package com.njzscloud.supervisory.sys.stationletter.mapper;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.njzscloud.supervisory.order.pojo.result.OrderPagingResult;
import com.njzscloud.supervisory.sys.stationletter.pojo.StationLetterEntity;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 站内信Mapper接口
 */
@Mapper
public interface StationLetterMapper {

    /**
     * 查询待处理的预警数据（站内信）
     */
    List<StationLetterEntity> selectPendingWarnList();

    /**
     * 查询待审核的公司数量
     */
    int selectPendingCompanyCount();

    /**
     * 查询待审核的车辆数量
     */
    int selectPendingTruckCount();

    /**
     * 查询待审核的项目数量
     */
    int selectPendingProjectCount();

    /**
     * 查询待审核的司机数量
     */
    int selectPendingDriverCount();

    int selectPendingKlyOrderCount(@Param("ew") QueryWrapper<OrderPagingResult> ew);

    /**
     * 查询待审核的订单数量
     */
    int selectPendingOrderCount(@Param("ew") QueryWrapper<OrderPagingResult> ew);

}
